#.------------------------------------------------------------,
#| Compact Flash Builder - IBM Embedded Linux Network Station |
#|                                                            |
#| This code originally developed by:                         |
#| Ryan Harper and Christopher Glendenning                    |
#| March, April 2000                                          |
#|                                                            |
#| Filename: genutils.tcl                                     |
#| Last Modified: April 21, 2000 by Ryan Harper               |
#| Changes: added cf_partition, cf_format, and cf_mount       |
#|          04.26.00 RAH                                      |  
#|          fixed install overlap 04.26.00 RAH                |
#|          added return vals for procs 04.21.00 RAH          |
#|          modified run_build_script 04.11.00 RAH            |
#|          modified SaveDirInfo 04.10.00 RAH                 |
#| Description: Contains all of the generic functions the     |
#|     Compact Flash Builder uses. Implemented in v2.3 to     |
#|     increase speed and good code design through modularity |
#`------------------------------------------------------------'

#.------------------------------------------------------------,
#| Generic Display Functions                                  |
#|                                                            |
#| Makes a generic text display dialog, uses dialog_create,   |
#| dialog_info                                                |
#`------------------------------------------------------------'

proc textdisplay_create {{title "File 1"}} {
    set top [dialog_create Textdisplay]
    wm title $top $title
    set info [dialog_info $top]
    scrollbar $info.sbar -command "$info.text yview"
    pack $info.sbar -side right -fill y
    text $info.text -wrap word -yscrollcommand "$info.sbar set"
    pack $info.text -side left -expand yes -fill both

    set cntls [dialog_controls $top]
    button $cntls.dismiss -text "Done" -command "destroy $top"
    pack $cntls.dismiss -pady 4
    focus $cntls.dismiss

    $info.text configure -state disabled
    $info.text tag configure normal -spacing1 6p -font\
      -*-helvetica-medium-r-normal--*120-*
    $info.text tag configure heading -spacing1 0.2i -font\
      -*-helvetica-bold-r-normal--*-120-*
    $info.text tag configure bold -font -*-helvetica-bold-r-normal--*-120-*
    $info.text tag configure italic -font -*-helvetica-medium-0-normal--*-120-*
    $info.text tag configure typewriter -wrap none -font\
      -*-courier-medium-r-normal--*-120-*
    return $top
}


#.------------------------------------------------------------,
#|                                                            |
#|                                                            |
#`------------------------------------------------------------'
#  Appends text to a generic dialogbox, uses
#  dialog_info

proc textdisplay_append {top mesg {tag "normal"}} {
    set info [dialog_info $top]

    $info.text configure -state normal
    $info.text insert end $mesg $tag
    $info.text configure -state disabled
}

#.------------------------------------------------------------,
#|                                                            |
#|                                                            |
#`------------------------------------------------------------'
#  Clears all text from a generic dialogbox, uses
#  dialog_info

proc textdisplay_clear {top} {
    set info [dialog_info $top]

    $info.text configure -state normal
    $info.text delete 1.0 end
    $info.text configure -state disabled
}

#.------------------------------------------------------------,
#|                                                            |
#|                                                            |
#`------------------------------------------------------------'
#  Displays text from a file in a generic dialogbox, uses
#  dialog_info

proc textdisplay_file {top fname} {
    set info [dialog_info $top]
    set fid [open $fname r]
    set contents [read $fid]
    close $fid
    $info.text configure -state normal
    $info.text delete 1.0 end
    $info.text insert end $contents "typewriter"
    $info.text configure -state disabled
}

#.------------------------------------------------------------,
#|                                                            |
#|                                                            |
#`------------------------------------------------------------'
#  Creates a generic dialog box, text area and controls section, uses
#  toplevel, wm, frame, pack 

proc dialog_create {class {win "auto"}} {
    if {$win == "auto"} {
	set count 0
	set win ".dialog[incr count]"
	while {[winfo exists $win]} {
	    set win ".dialog[incr count]"
	}
    }

    toplevel $win -class $class
    #wm geometry $win +250+250
    centerwin $win
    frame $win.info
    pack $win.info -expand yes -fill both -padx 2 -pady 2
    frame $win.sep -height 2 -borderwidth 1 -relief sunken
    pack $win.sep -fill x -pady 4
    frame $win.controls
    pack $win.controls -fill x -padx 4 -pady 4
    wm title $win $class

    wm group $win .
    after idle [format {
		    update idletasks
		    wm minsize %s [winfo reqwidth %s] [winfo reqheight %s]
	    } $win $win $win]
    return $win
}

proc dialog_info {win} {
    return "$win.info"
}

proc dialog_controls {win} {
    return "$win.controls"
}

#.------------------------------------------------------------,
#|                                                            |
#|                                                            |
#`------------------------------------------------------------'
#  makes an OK Cancel dialog box for a function, uses
#  dialog_create, dialog_info

proc confirm_ask {mesg {ok "OK"} {cancel "Cancel"}} {

    global confirmStatus
    set top [dialog_create Confirm]
    set info [dialog_info $top]
    #wm geometry $top +250+250
    centerwin $top
    label $info.icon
    pack $info.icon -side left -padx 8 -pady 8
    label $info.mesg -text $mesg
    pack $info.mesg -side right -expand yes -fill both -padx 8 -pady 8
    set cntls [dialog_controls $top]
    button $cntls.ok -text $ok -command {set confirmStatus 1}
    pack $cntls.ok -side left -expand yes
    button $cntls.cancel -text $cancel -command {set confirmStatus 0}
    pack $cntls.cancel -side left -expand yes
    focus $cntls.ok

    wm protocol $top WM_DELETE_WINDOW "$cntls.cancel invoke"
    dialog_wait $top confirmStatus
    destroy $top
    return $confirmStatus
}

#.------------------------------------------------------------,
#|                                                            |
#|                                                            |
#`------------------------------------------------------------'
#  used to wait for computer to respond

proc dialog_wait {win varName} {
    dialog_safeguard $win
    set x [expr [winfo rootx .]+50]
    set y [expr [winfo rooty .]+50]
#    wm geometry $win "+$x+$y"
    centerwin $win
    wm deiconify $win
    grab set $win
    vwait $varName
    grab release $win
    wm withdraw $win
}

proc dialog_safeguard {win} {
    if {[lsearch [bindtags $win] modalDialog] < 0} {
	bindtags $win [linsert [bindtags $win] 0 modalDialog]
    }
}

bind modalDialog <ButtonPress> {
    wm deiconify %W
    raise %W
}

#.------------------------------------------------------------,
#|                                                            |
#|                                                            |
#`------------------------------------------------------------'
#  generic window to show install progress
#  pass it the starting message, the action
#  like "/myscript.sh" and it will exec it,
#  store the output in log, and update window
#  with end mesg

proc action_window {start_mesg action log end_mesg} {
    global lh
    global logfilename
    puts $lh [format "%s" "Starting action_window"]
    puts $lh [format "%s:\n\t--%s\n\t--%s\n\t--%s\n\t--%s" "Passed Vars"\
      "$start_mesg" "$action" "$log" "$end_mesg"]
    flush $lh

    global CFBUILD_DIR_NO_SLASH
    global SCRIPT_DIR
    update
    toplevel .action -width 250 -height 150
    wm resizable .action 0 0
    wm title .action "Executing $action"
    label .action.message -text $start_mesg
    pack .action.message -padx 50 -pady 50
    #wm geometry .action +360+340
    centerwin .action
    update
    cd $CFBUILD_DIR_NO_SLASH/$SCRIPT_DIR
    puts $lh [format "%s" "Executing $action"]
    flush $lh
    exec $action >>&$CFBUILD_DIR_NO_SLASH/Log/$logfilename
    set lh [open $CFBUILD_DIR_NO_SLASH/Log/$logfilename a]    
    cd $CFBUILD_DIR_NO_SLASH
    .action.message configure -text $end_mesg
    after 1000
    destroy .action
    return
}

#.------------------------------------------------------------,
#|                                                            |
#|                                                            |
#`------------------------------------------------------------'
#  same as action_window, but execs a proc, instead 
#  of a script

proc action_window_proc {start_mesg action log end_mesg} {
    global lh
    puts $lh [format "%s" "Starting action_window_proc"]
    puts $lh [format "%s:\n\t--%s\n\t--%s\n\t--%s\n\t--%s" "Passed Vars"\
      "$start_mesg" "$action" "$log" "$end_mesg"]
    flush $lh

    global CFBUILD_DIR_NO_SLASH
    global SCRIPT_DIR
    update
    toplevel .action_proc -width 250 -height 150
    wm resizable .action_proc 0 0
    wm title .action_proc " "
    label .action_proc.message -text $start_mesg
    pack .action_proc.message -padx 50 -pady 50
    #wm geometry .action_proc +360+340
    centerwin .action_proc
    update
    cd $CFBUILD_DIR_NO_SLASH/$SCRIPT_DIR
    ${action}
    cd $CFBUILD_DIR_NO_SLASH
    .action_proc.message configure -text $end_mesg
    after 1000
    destroy .action_proc
    return
}

#.------------------------------------------------------------,
#|                                                            |
#|                                                            |
#`------------------------------------------------------------'
#center the windows
#Pre: passed a window object which exists
#Post: window object is now centered

proc centerwin {winname} {
    set xmax [winfo screenwidth $winname]
    set ymax [winfo screenheight $winname]
    set x [expr ($xmax-[winfo reqwidth $winname])/2]
    set y [expr ($ymax-[winfo reqheight $winname])/2]
    wm geometry $winname "+$x+$y"
}

proc check_for_win {winname} {
    if {[winfo exists $winname]==1} {
	set temp [focus -lastfor $winname]
	focus $temp
	raise $winname
	return true
    } {
	return false
    }
}

proc cf_partition {} {
    global CFBUILD_DIR_NO_SLASH
    global SCRIPT_DIR
    global lh
    global logfilename

    puts $lh [format "%s" "Starting cf_partition"]
    flush $lh

    puts $lh [format "%s" "\tUnmounting devices"]
    flush $lh
    update
    exec $CFBUILD_DIR_NO_SLASH/$SCRIPT_DIR/cf_umount.sh &
    after 1000
    set lh [open $CFBUILD_DIR_NO_SLASH/Log/$logfilename a]


    cd $CFBUILD_DIR_NO_SLASH/Log
    set filename "sfdisk.out"
    set fh [open $filename w]
    fconfigure $fh

    exec sfdisk -g /dev/hda >@ $fh
    close $fh

    set sfh [open $filename r]
    set string [gets $sfh]
    close $sfh
    set list [split $string]

    set cyl [lindex $list 1]
    set head [lindex $list 3]
    set sect [lindex $list 5]
    set ram_disk_size "32"
    set size_var [expr $cyl * $head]
    set total_size [expr $cyl * $head * $sect]

    set part1_start $sect
    set part2_start [expr {[expr $cyl - $ram_disk_size]} * $head * $sect]
    set part1_size [expr $part2_start - 32]
    set part2_size [expr $total_size - $part2_start]


    set pfname "partition.out"
    set pfh [open $pfname w]
    fconfigure $pfh

    puts $pfh [format "%s" "# partition table of /dev/hda "]
    puts $pfh [format "%s" "unit: sectors"]
    puts $pfh [format "%s" "\n"]
    puts $pfh [format "%s" "/dev/hda1 : start= $part1_start, size= $part1_size, Id=83"]
    puts $pfh [format "%s" "/dev/hda2 : start= $part2_start, size= $part2_size, Id=83"]
    puts $pfh [format "%s" "/dev/hda3 : start=        0, size=       0, Id= 0"]
    puts $pfh [format "%s" "/dev/hda4 : start=        0, size=       0, Id= 0"]
    flush $pfh
    close $pfh    

    update
    toplevel .top -width 250 -height 150
    wm title .top "Partitioning Flash"
    label .top.message -text "Partitioning... Please Wait."
    pack .top.message -padx 50 -pady 50
    wm geometry .top +360+340
    update idletasks
    exec sfdisk --force /dev/hda < partition.out >>&$logfilename
    .top.message configure -text "Complete"
    after 1000
    destroy .top
    update

    set lh [open $CFBUILD_DIR_NO_SLASH/Log/$logfilename a]
    puts $lh [format "%s" "auto_partition complete"]
    flush $lh
    return
}

proc cf_format {} {
    global CFBUILD_DIR_NO_SLASH
    global SCRIPT_DIR
    global lh
    global logfilename

    puts $lh [format "%s" "Starting cf_format"]
    flush $lh

    puts $lh [format "%s" "\tUnmounting devices"]
    flush $lh
    update
    exec $CFBUILD_DIR_NO_SLASH/$SCRIPT_DIR/cf_umount.sh &
    after 1000
    set lh [open $CFBUILD_DIR_NO_SLASH/Log/$logfilename a]
    puts $lh [format "%s" "\tFormating"]
    flush $lh

    update
    toplevel .top -width 250 -height 150
    wm title .top "Formatting Flash"
    label .top.message -text "Formatting Flash... Please Wait."
    pack .top.message -padx 50 -pady 50
    wm geometry .top +360+340
    update idletasks
    exec mke2fs /dev/hda1 >>& $logfilename
    exec mke2fs /dev/hda2 >>& $logfilename
    .top.message configure -text "Complete"
    after 1000
    destroy .top
    update

    set lh [open $CFBUILD_DIR_NO_SLASH/Log/$logfilename a]
    puts $lh [format "%s" "cf_format complete"]
    flush $lh
    return
}

proc cf_mount {} {
    global CFBUILD_DIR_NO_SLASH
    global lh
    global logfilename

    puts $lh [format "%s" "Starting cf_mount"]
    flush $lh

    update
    toplevel .top -width 250 -height 150
    wm title .top "Mounting Flash"
    label .top.message -text "Mounting Flash... Please Wait."
    pack .top.message -padx 50 -pady 50
    wm geometry .top +360+340
    update idletasks
    exec mkdir -p /mnt/hd1 >>& $logfilename
    exec mkdir -p /mnt/hd2 >>& $logfilename
    exec mount /dev/hda1 /mnt/hd1 >>& $logfilename
    exec mount /dev/hda2 /mnt/hd2 >>& $logfilename
    .top.message configure -text "Complete"
    after 1000
    destroy .top
    update

    set lh [open $CFBUILD_DIR_NO_SLASH/Log/$logfilename a]
    puts $lh [format "%s" "cf_mount complete"]
    flush $lh
    return
}

#.------------------------------------------------------------,
#|                                                            |
#|                                                            |
#`------------------------------------------------------------'
#  generic install program function, pass message,

proc install_program {mesg build_cmd help_cmd} {
    global lh
    puts $lh [format "%s" "Starting install_program"]
    puts $lh [format "%s:\n\t--%s\n\t--%s\n\t--%s" "Passed Vars" "$mesg"\
      "$build_cmd" "$help_cmd"]
    flush $lh

    .win.right.startmesg configure -justify "left" -text $mesg
    update
    if {[winfo exists .win.rightbottom.build] == 0} {
	button .win.rightbottom.build -text {Build Package} -state normal\
	  -command $build_cmd
	place .win.rightbottom.build -x 0 -y 10
	return
    } {
	.win.rightbottom.build configure -text {Build Package} -state normal\
	  -command $build_cmd
    }
    .win.rightbottom.install configure -width 15 -text {Help} -state normal\
      -command $help_cmd
}

#.------------------------------------------------------------,
#|                                                            |
#|                                                            |
#`------------------------------------------------------------'
proc show_help_file {infile winname} {
    global CFBUILD_DIR_NO_SLASH
    global INSTALLDOC_DIR
    global lh
    puts $lh [format "%s" "Starting show_help_file"]
    puts $lh [format "%s:\n\t--%s\n\t--%s" "Passed Vars" "$infile" "$winname"]
    flush $lh


    cd $CFBUILD_DIR_NO_SLASH/$INSTALLDOC_DIR
    set in $infile
    set win [textdisplay_create $winname]
    textdisplay_file $win $in
    cd $CFBUILD_DIR_NO_SLASH
}

proc view_log {} {
    global CFBUILD_DIR_NO_SLASH
    global lh
    global logfilename
    puts $lh [format "%s" "Starting view_log"]
    flush $lh


    set in $CFBUILD_DIR_NO_SLASH/Log/$logfilename
    set win [textdisplay_create $logfilename]
    textdisplay_file $win $in
}

#.------------------------------------------------------------,
#|                                                            |
#|                                                            |
#`------------------------------------------------------------'
proc get_dir {prompt save_type num_browse cmd} {
    global lh
    puts $lh [format "%s" "Starting get_dir"]
    puts $lh [format "%s:\n\t--%s\n\t--%s\n\t--%s" "Passed Vars" "$prompt"\
      "$save_type" "$num_browse" "$cmd"]
    flush $lh

    global i
    global types
    global a_path
    global return_val
    set return_val 0

    if {[winfo exists .win.]} {
	wm deiconify .win
	return
    }


    set wh [expr 70 + $num_browse * 38]
    toplevel .win.top -width 250 -height $wh
    wm title .win.top "Find Install Files"
    label .win.top.message -text $prompt
    centerwin .win.top
    button .win.top.done -width 7 -text {Done} -command "${cmd} ${save_type}\
      ${num_browse}"

    set e_y_val "50"
    set e_space "28"
    set b_y_val "45"
    set b_space "30"
    for {set i 0} {$i < $num_browse} {incr i} {
	button .win.top.browse$i -width 7 -text "Browse" -command {browse "$i"}
	entry .win.top.entry$i
	place .win.top.entry$i -x 15 -y $e_y_val
	place .win.top.browse$i -x 170 -y $b_y_val
	set e_y_val [expr $e_y_val + $e_space]
	set b_y_val [expr $b_y_val + $b_space]
    }
    set i "0"
    place .win.top.message -x 10 -y 12
    place .win.top.done -x 170 -y [expr $wh - 32]

    proc browse {index} {
	global i
	global types
	global a_path
	set a_path($index) [tk_getOpenFile -title "Find Install Source"\
	  -filetypes $types -parent .win.top]
	.win.top.entry$index insert 0 $a_path($index)
	.win.top.entry$index select range 0 [string length $a_path($index)]
	focus .win.top.entry$index
	incr i
	return

    }

    #.------------------------------------------------------------,
    #|                                                            |
    #|                                                            |
    #`------------------------------------------------------------'
    #  function ($save_type $num_browse)

    proc finish {buildcmd save_type num_browse} {
	global proceed
	global lh
	puts $lh [format "%s" "Starting finish"]
	puts $lh [format "%s:\n\t--%s\n\t--%s\n\t--%s" "Passed Vars"\
	  "$buildcmd" "$save_type" "$num_browse"]
	flush $lh

	global a_path

	SaveDirInfo $save_type $num_browse
	destroy .win.top
	set proceed [run_build_script $buildcmd]
	return $proceed
    }

}

#.------------------------------------------------------------,
#|                                                            |
#|                                                            |
#`------------------------------------------------------------'

proc run_build_script {install} {
    global lh
    puts $lh [format "%s" "Starting run_build_script"]
    puts $lh [format "%s:\n\t--%s" "Passed Vars" "$install"]
    flush $lh

    if {[winfo exists .win.rightbottom.build] == 1} {
	.win.rightbottom.build configure -text {Working...} -state disabled
	.win.rightbottom.install configure -state disabled
	.win.left.ica configure -state disabled
	.win.left.netscape configure -state disabled
	.win.left.gimp configure -state disabled
	.win.left.real7 configure -state disabled
	.win.left.jvm configure -state disabled
	update idletasks
	$install
	#            tk_messageBox -message "running $install"
	destroy .win.rightbottom.build
	update
	if {[winfo exists .win.rightbottom.done] == 0} {
	    label .win.rightbottom.done -text "Done"
	    place .win.rightbottom.done -x 0 -y 10
	}
	.win.left.ica configure -state normal
	.win.left.netscape configure -state normal
	.win.left.gimp configure -state normal
	.win.left.real7 configure -state normal
	.win.left.jvm configure -state normal
	.win.right.startmesg configure -justify "left" -text\
	  "\tInstallation Complete.\n\n Please select another package to\
	  install\n or click Next to continue.\n\n"
    } {
	update idletasks
	$install
	return 1
    }
	return 0
}

proc unpack_tar {start_mesg package_name end_mesg} {
    global lh
    puts $lh [format "%s" "Starting unpack_tar"]
    puts $lh [format "%s:\n\t--%s\n\t--%s\n\t--%s" "Passed Vars" "$start_mesg"\
      "$package_name" "$end_mesg"]
    flush $lh

    global CFBUILD_DIR_NO_SLASH

    update
    toplevel .top -width 250 -height 150
    wm title .top "Install"
    wm resizable .top 0 0
    label .top.message -text $start_mesg
    pack .top.message -padx 50 -pady 50
    centerwin .top
    update
    set workingdir [pwd]
    cd /mnt/hd1
    exec tar -xzf $CFBUILD_DIR_NO_SLASH/Packages/$package_name
    cd $workingdir
    .top.message configure -text $end_mesg
    after 1000
    destroy .top
    return 1
}


#.------------------------------------------------------------,
#|                                                            |
#|                                                            |
#`------------------------------------------------------------'
#  exit the program

proc exit {} {
    global lh
    puts $lh [format "%s" "Exiting Program (command=destroy .)"]
    flush $lh
    destroy .
}

#.------------------------------------------------------------,
#|                                                            |
#|                                                            |
#`------------------------------------------------------------'
#  confirm dialog exit
proc cexit {} {
    global lh
    puts $lh [format "%s" "Exiting Program (command=confirm_exit)"]
    flush $lh

    if {[confirm_ask "Do you really want to quit?"]} {
	destroy .
    }
}

#.------------------------------------------------------------,
#|                                                            |
#|                                                            |
#`------------------------------------------------------------'

proc MOO {} {
    global lh
    puts $lh [format "%s" "Exiting Program (command=MOO - You have been\
      destroyed by a cow)"]
    flush $lh

    destroy .
}

#.------------------------------------------------------------,
#|                                                            |
#|                                                            |
#`------------------------------------------------------------'

proc ChangePage {nextwin runwizard} {
    global lh
    puts $lh [format "%s-> %s" "Changing Pages" "$nextwin"]
    flush $lh

    destroy .win
    $nextwin $runwizard
}

#.------------------------------------------------------------,
#|                                                            |
#|                                                            |
#`------------------------------------------------------------'

proc SaveInstallDir {var1 var2} {
    global lh
    puts $lh [format "%s" "Starting SaveInstallDir"]
    puts $lh [format "%s:\n\t--%s\n\t--%s" "Passed Vars" "$var1" "$var2"]
    flush $lh


    set filename "/root/IBM/InstallDir"
    set fd [open $filename w]
    fconfigure $fd
    puts $fd [format "%s=%s" "install_dest" $var1]
    puts $fd [format "%s=%s" "install_source" $var2]
    close $fd
    exec chmod a+x /root/IBM/InstallDir
    exec sync
}

#.------------------------------------------------------------,
#|                                                            |
#|                                                            |
#`------------------------------------------------------------'
#  SaveDirInfo $save_type $num_browse 

proc SaveDirInfo {type numvals} {
    global lh
    global a_path
    puts $lh [format "%s" "Starting SaveDirInfo"]
    puts $lh [format "%s:\n\t--%s\n\t--%s" "Passed Vars" "$type" "$numvals"]
    for {set x 0} {$x < $numvals} {incr x} {
	puts $lh [format "%s:\n\t--%s=%s" "Saving" "$type" "$a_path($x)"]
    }
    flush $lh


    global BOOTDIR
    global logfilename
    global NETSCAPE_ROOT
    global IBM_JVM_ROOT
    global REAL7_ROOT
    global INSTALL_DEST
    global INSTALL_SOURCE
    global FVWM2_SOURCE
    global FVWM2_ICON_SOURCE
    global GIMP_SOURCE
    global GIMP_LIB_SOURCE
    global GTK_SOURCE
    global REAL7_SOURCE
    global IBM_JVM_SOURCE
    global BACKUP_SOURCE
    global RESTORE_SOURCE
    global ICA_SOURCE
    global CFBUILD_DIR_NO_SLASH
    global CFBUILD_DIR
    global CUSTOM_DIR
    global INSTALLDOC_DIR
    global SCRIPT_DIR
    global PARTITION_DIR

    if {$numvals >= 1} {
	#    tk_messageBox -message "$type\n$numvals\n$a_path(0)"

	switch $type {
	netscape {
		#           tk_messageBox -message "Netscape Type"
		set NETSCAPE_ROOT "$a_path(0)"
		#           tk_messageBox -message $NETSCAPE_ROOT
	    }
	jvm {
		#           tk_messageBox -message "IBM JVM"
		set IBM_JVM_SOURCE "$a_path(0)"
		#	    tk_messageBox -message $IBM_JVM_SOURCE
	    }
	gimp {
		#           tk_messageBox -message "Gimp"
		set GIMP_SOURCE "$a_path(0)"
		set GIMP_LIB_SOURCE "$a_path(1)"
		set GTK_SOURCE "$a_path(2)"
		#	    tk_messageBox\
		  -message "$GIMP_SOURCE\n$GIMP_LIB_SOURCE\n$GTK_SOURCE"
	    }
	ica {
		#           tk_messageBox -message "ica"
		set ICA_SOURCE "$a_path(0)"
		#	    tk_messageBox -message "$ICA_SOURCE"
	    }
	real7 {
		#           tk_messageBox -message "real7"
		set REAL7_SOURCE "$a_path(0)"
		#	    tk_messageBox -message $REAL7_SOURCE
	    }
	backup {
		set BACKUP_SOURCE "$a_path(0)"
	    }
	restore {
		set RESTORE_SOURCE "$a_path(0)"
	    }
	fvwm2 {
		set FVWM2_SOURCE "$a_path(0)"
		set FVWM2_ICON_SOURCE "$a_path(1)"
	    }
	}
    } ;# end if clause

    exec mkdir -p /root/IBM/
    set filename "/root/IBM/DirInfo"
    set fd [open $filename w]
    fconfigure $fd
    puts $fd [format "%s=%s" "bootdir" $BOOTDIR]
    puts $fd [format "%s=%s" "logfilename" $logfilename]
    puts $fd [format "%s=%s" "netscape_root" $NETSCAPE_ROOT]
    puts $fd [format "%s=%s" "ibm_jvm_root" $IBM_JVM_ROOT]
    puts $fd [format "%s=%s" "real7_root" $REAL7_ROOT]
    puts $fd [format "%s=%s" "install_dest" $INSTALL_DEST]
    puts $fd [format "%s=%s" "install_source" $INSTALL_SOURCE]
    puts $fd [format "%s=%s" "fvwm2_source" $FVWM2_SOURCE]
    puts $fd [format "%s=%s" "fvwm2_icon_source" $FVWM2_ICON_SOURCE]
    puts $fd [format "%s=%s" "gimp_source" $GIMP_SOURCE]
    puts $fd [format "%s=%s" "gimp_lib_source" $GIMP_LIB_SOURCE]
    puts $fd [format "%s=%s" "gtk_source" $GTK_SOURCE]
    puts $fd [format "%s=%s" "real7_source" $REAL7_SOURCE]
    puts $fd [format "%s=%s" "ibm_jvm_source" $IBM_JVM_SOURCE]
    puts $fd [format "%s=%s" "backup_source" $BACKUP_SOURCE]
    puts $fd [format "%s=%s" "restore_source" $RESTORE_SOURCE]
    puts $fd [format "%s=%s" "ica_source" $ICA_SOURCE]
    puts $fd [format "%s=%s" "cfbuild_dir" $CFBUILD_DIR_NO_SLASH]
    puts $fd [format "%s=%s" "custom_dir" $CUSTOM_DIR]
    puts $fd [format "%s=%s" "installdoc_dir" $INSTALLDOC_DIR]
    puts $fd [format "%s=%s" "script_dir" $SCRIPT_DIR]
    puts $fd [format "%s=%s" "partition_dir" $PARTITION_DIR]

    close $fd
    exec chmod a+x /root/IBM/DirInfo
    exec sync


}
